// $Id: tideEditor.h 4046 2011-09-07 21:43:34Z flaterco $

/* TideEditor class definition.  */

/*****************************************************************************\

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

\*****************************************************************************/


#ifndef TIDEEDITOR_H
#define TIDEEDITOR_H

/* RWL the following ifdef removes a templates error when compiling with MSVC (Known bug) */

#ifdef WIN32
#include <math.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <qapplication.h>
#include <qevent.h>
#include <qpainter.h>
#include <q3toolbar.h>
#include <qtoolbutton.h>
#include <q3popupmenu.h>
#include <qmenubar.h>
#include <qstatusbar.h>
#include <q3hbox.h>
#include <q3vbox.h>
#include <qmessagebox.h>
#include <qtooltip.h>
#include <qrect.h>
#include <qpoint.h>
#include <qcolordialog.h>
#include <q3filedialog.h>
#include <qcursor.h>
#include <qimage.h>
#include <q3strlist.h>
#include <q3intdict.h>
#include <q3whatsthis.h>
#include <qaction.h>
#include <q3mainwindow.h>
#include <q3rangecontrol.h>
#include <qpen.h>
#include <qpoint.h>
#include <qpixmap.h>
#include <qwidget.h>
#include <qstring.h>
#include <q3pointarray.h>
#include <qradiobutton.h>
#include <q3buttongroup.h>
#include <q3listbox.h>
#include <qsettings.h>
//Added by qt3to4:
#include <QMouseEvent>
#include <QKeyEvent>

#include <tcd.h>
#include "map.h"


char *fixpos (double degs, double *deg, double *min, double *sec, char *hem,
              char *c_type, char *c_form);
void posfix (char *string, double *degs, char *c_type);


typedef struct
{
    int  recnum;
    char *name;
    double latitude;
    double longitude;
} STATION_LIST;


class QToolButton;
class QAction;


class TideEditor;
class TideList;

class TideEditor:public Q3MainWindow
{
    Q_OBJECT 


  public:

    TideEditor (const char *hfile_in, QWidget *parent = 0, const char *name = 0);
    ~TideEditor ();

    void setRedrawZeroLevel ();
    void redrawMap ();
    void highlightStation (double lat, double lon, unsigned char record_type);

    int size, number_of_records;


    STATION_LIST *station_list;


    char pos_format[10];
      

    TideList *tideList;


  protected:

    char hfile[512];

    NV_BOOL readonly;

    Map *map;

    DB_HEADER_PUBLIC db;
    TIDE_RECORD rec;

    QColor refStationColor, subStationColor;
    Q3ButtonGroup *bGrp;
    QDialog *prefsD, *searchD;
    Q3ListBox *searchList;
    QLineEdit *searchName;
    int lastrec;

    QToolButton    *bQuit, *bZoomOut, *bReset, *bLeft, *bUp, *bDown, *bRight, 
                   *bPrefs, *bDisaster, *bSearch;

    QSettings settings;

    void plotStations ();
    void envin ();
    void envout ();


  protected slots:

    void slotRedraw ();
    void slotLeftMouse (QMouseEvent * e);
    void slotMidMouse (QMouseEvent * e);
    void slotRightMouse (QMouseEvent * e);
    void slotMouseMove (QMouseEvent * e);

    void slotQuit ();
    void slotDisaster ();

    void slotPrefs ();
    void slotPrefsClicked ();
    void slotClosePrefs ();
    void slotCloseSearch ();
    void slotSelected ();
    void slotHighlighted ();
    void slotTextChanged ();
    void slotSearch ();
    void slotRefColor ();
    void slotSubColor ();
    void slotZoomOut ();
    void slotReset ();

    void slotUp ();
    void slotDown ();

    void slotRight ();
    void slotLeft ();

    void about ();
    void aboutQt ();

  private:
    void keyPressEvent (QKeyEvent * e);
};

#endif
